# Spectrum API Service

Es un paquete que tiene como propósito facilitar la comunicación con 
la API de SPECTRUM a través de Python.

## Instalación
`pip install spectrum-api-service-bit3`


## Creadores

Mauricio Montoya Medrano